@@ -53,10 +53,10 @@ struct _XfdashboardApplicationPrivate
 {
 	/* Properties related */
 	gboolean					isDaemon;
+	gboolean					isSuspended;
 
 	/* Instance related */
 	gboolean					inited;
-	gboolean					shouldInit;
 	XfconfChannel				*xfconfChannel;
 	XfdashboardViewManager		*viewManager;
 };
@@ -67,6 +67,7 @@ enum
 	PROP_0,
 
 	PROP_DAEMONIZED,
+	PROP_SUSPENDED,
 
 	PROP_LAST
 };
@@ -78,6 +79,8 @@ enum
 {
 	SIGNAL_QUIT,
 	SIGNAL_SHUTDOWN_FINAL,
+	SIGNAL_SUSPEND,
+	SIGNAL_RESUME,
 
 	SIGNAL_LAST
 };
@@ -85,26 +88,9 @@ enum
 static guint XfdashboardApplicationSignals[SIGNAL_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
-
 #define XFDASHBOARD_APP_ID				"de.froevel.nomad.xfdashboard"
 #define XFDASHBOARD_XFCONF_CHANNEL		"xfdashboard"
 
-/* Application options */
-struct applicationOptions
-{
-	gboolean	doDaemonize;
-	gboolean	doReplace;
-	gboolean	doQuit;
-} applicationOptions;
-
-const GOptionEntry XfdashboardApplicationOptions[]=
-	{
-		{"daemonize", 'd', 0, G_OPTION_ARG_NONE, &applicationOptions.doDaemonize, N_("Fork to background"), NULL},
-		{"restart", 'r', 0, G_OPTION_ARG_NONE, &applicationOptions.doReplace, N_("Replace existing instance"), NULL},
-		{"quit", 'q', 0, G_OPTION_ARG_NONE, &applicationOptions.doQuit, N_("Quit existing instance"), NULL},
-		{NULL}
-	};
-
 /* Single instance of application */
 static XfdashboardApplication*		application=NULL;
 
@@ -124,25 +110,35 @@ static void _xfdashboard_application_quit(XfdashboardApplication *self, gboolean
 	if(inForceQuit==TRUE || priv->isDaemon==FALSE) shouldQuit=TRUE;
 
 	/* If application is not in daemon mode or if forced is set to TRUE
-	 * destroy all stage windows. Otherwise just hide them.
+	 * destroy all stage windows ...
 	 */
-	stages=clutter_stage_manager_list_stages(clutter_stage_manager_get_default());
-	for(entry=stages; entry!=NULL; entry=g_slist_next(entry))
-	{
-		if(shouldQuit==TRUE) clutter_actor_destroy(CLUTTER_ACTOR(entry->data));
-			else clutter_actor_hide(CLUTTER_ACTOR(entry->data));
-	}
-	g_slist_free(stages);
-
-	/* Quit main loop if we should */
 	if(shouldQuit==TRUE)
 	{
+		/* Destroy stages */
+		stages=clutter_stage_manager_list_stages(clutter_stage_manager_get_default());
+		for(entry=stages; entry!=NULL; entry=g_slist_next(entry)) clutter_actor_destroy(CLUTTER_ACTOR(entry->data));
+		g_slist_free(stages);
+
 		/* Emit "quit" signal */
 		g_signal_emit(self, XfdashboardApplicationSignals[SIGNAL_QUIT], 0);
 
 		/* Really quit application here and now */
 		if(priv->inited) clutter_main_quit();
 	}
+		/* ... otherwise emit "suspend" signal */
+		else
+		{
+			/* Only send signal if not suspended already */
+			if(!priv->isSuspended)
+			{
+				/* Send signal */
+				g_signal_emit(self, XfdashboardApplicationSignals[SIGNAL_SUSPEND], 0);
+
+				/* Set flag for suspension */
+				priv->isSuspended=TRUE;
+				g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_SUSPENDED]);
+			}
+		}
 }
 
 /* A stage window should be destroyed */
@@ -196,7 +192,7 @@ static gboolean _xfdashboard_application_initialize_full(XfdashboardApplication
 	 */
 	stage=xfdashboard_stage_new();
 
-	clutter_actor_show(stage);
+	if(!priv->isDaemon) clutter_actor_show(stage);
 	g_signal_connect_swapped(stage, "delete-event", G_CALLBACK(_xfdashboard_application_on_delete_stage), self);
 
 	/* Initialization was successful so return TRUE */
@@ -212,22 +208,6 @@ static gboolean _xfdashboard_application_initialize_full(XfdashboardApplication
 
 /* Received "activate" signal on primary instance */
 static void _xfdashboard_application_activate(GApplication *inApplication)
-{
-	GSList							*stages, *entry;
-
-	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inApplication));
-
-	/* Show all stages again */
-	stages=clutter_stage_manager_list_stages(clutter_stage_manager_get_default());
-	for(entry=stages; entry!=NULL; entry=g_slist_next(entry))
-	{
-		clutter_actor_show(CLUTTER_ACTOR(stages->data));
-	}
-	g_slist_free(stages);
-}
-
-/* Primary instance is starting up */
-static void _xfdashboard_application_startup(GApplication *inApplication)
 {
 	XfdashboardApplication			*self;
 	XfdashboardApplicationPrivate	*priv;
@@ -237,13 +217,15 @@ static void _xfdashboard_application_startup(GApplication *inApplication)
 	self=XFDASHBOARD_APPLICATION(inApplication);
 	priv=self->priv;
 
-	/* Call parent's class startup method */
-	G_APPLICATION_CLASS(xfdashboard_application_parent_class)->startup(inApplication);
+	/* Emit "resume" signal */
+	g_signal_emit(self, XfdashboardApplicationSignals[SIGNAL_RESUME], 0);
 
-	/* Set flag indicating that command-line handler
-	 * should initialize this instance as it is the primary one
-	 */
-	priv->shouldInit=TRUE;
+	/* Unset flag for suspension */
+	if(priv->isSuspended)
+	{
+		priv->isSuspended=FALSE;
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_SUSPENDED]);
+	}
 }
 
 /* Handle command-line on primary instance */
@@ -256,6 +238,14 @@ static int _xfdashboard_application_command_line(GApplication *inApplication, GA
 	gint							argc;
 	gchar							**argv;
 	GError							*error;
+	gboolean						optionDaemonize;
+	gboolean						optionQuit;
+	GOptionEntry					XfdashboardApplicationOptions[]=
+									{
+										{"daemonize", 'd', 0, G_OPTION_ARG_NONE, &optionDaemonize, N_("Fork to background"), NULL},
+										{"quit", 'q', 0, G_OPTION_ARG_NONE, &optionQuit, N_("Quit existing instance"), NULL},
+										{NULL}
+									};
 
 	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATION(inApplication), 1);
 
@@ -264,16 +254,15 @@ static int _xfdashboard_application_command_line(GApplication *inApplication, GA
 	error=NULL;
 
 	/* Set up options */
+	optionDaemonize=FALSE;
+	optionQuit=FALSE;
+
 	context=g_option_context_new(N_("- A Gnome Shell like dashboard for Xfce4"));
 	g_option_context_add_group(context, gtk_get_option_group(TRUE));
 	g_option_context_add_group(context, clutter_get_option_group_without_init());
 	g_option_context_add_main_entries(context, XfdashboardApplicationOptions, GETTEXT_PACKAGE);
 
 	/* Parse command-line arguments */
-	applicationOptions.doDaemonize=FALSE;
-	applicationOptions.doReplace=FALSE;
-	applicationOptions.doQuit=FALSE;
-
 	argv=g_application_command_line_get_arguments(inCommandLine, &argc);
 	result=g_option_context_parse(context, &argc, &argv, &error);
 	g_strfreev(argv);
@@ -285,41 +274,45 @@ static int _xfdashboard_application_command_line(GApplication *inApplication, GA
 		return(XFDASHBOARD_APPLICATION_ERROR_FAILED);
 	}
 
-	/* Handle options: restart, quit */
-	if(applicationOptions.doReplace==TRUE || applicationOptions.doQuit==TRUE)
+	/* Handle options: quit */
+	if(optionQuit)
 	{
 		/* Quit existing instance */
 		g_debug(_("Quitting running instance!"));
 		_xfdashboard_application_quit(self, TRUE);
 
-		/* If we should just quit the running instance return here */
-		if(applicationOptions.doQuit==TRUE) return(XFDASHBOARD_APPLICATION_ERROR_QUIT);
-
-		/* If we get here we are going to replace the just quitted instance,
-		 * so force full initialization of this instance
-		 */
-		g_debug(_("Replacing running instance - force full initialization"));
-		priv->shouldInit=TRUE;
+		return(XFDASHBOARD_APPLICATION_ERROR_QUIT);
 	}
 
-	/* Handle options: daemonized */
-	priv->isDaemon=applicationOptions.doDaemonize;
-	g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_DAEMONIZED]);
+	/* Handle options: daemonize */
+	if(!priv->inited)
+	{
+		priv->isDaemon=optionDaemonize;
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_DAEMONIZED]);
+
+		if(!priv->isSuspended)
+		{
+			priv->isSuspended=TRUE;
+			g_object_notify_by_pspec(G_OBJECT(self), XfdashboardApplicationProperties[PROP_SUSPENDED]);
+		}
+	}
 
 	/* Check if this instance needs to be initialized fully */
-	if(priv->shouldInit==TRUE)
+	if(!priv->inited)
 	{
 		/* Perform full initialization of this application instance */
 		result=_xfdashboard_application_initialize_full(self);
 		if(result==FALSE) return(XFDASHBOARD_APPLICATION_ERROR_FAILED);
-
-		/* Prevent further accident initialization on this instance */
-		priv->shouldInit=FALSE;
 	}
 
+	/* Check if this instance need to be activated. Is should only be done
+	 * if instance is initialized
+	 */
+	if(priv->inited) _xfdashboard_application_activate(inApplication);
+
 	/* All done successfully so return status code 0 for success */
 	priv->inited=TRUE;
-	return(applicationOptions.doReplace==FALSE ? XFDASHBOARD_APPLICATION_ERROR_NONE : XFDASHBOARD_APPLICATION_ERROR_RESTART);
+	return(XFDASHBOARD_APPLICATION_ERROR_NONE);
 }
 
 /* IMPLEMENTATION: GObject */
@@ -379,6 +372,10 @@ static void _xfdashboard_application_get_property(GObject *inObject,
 			g_value_set_boolean(outValue, self->priv->isDaemon);
 			break;
 
+		case PROP_SUSPENDED:
+			g_value_set_boolean(outValue, self->priv->isSuspended);
+			break;
+
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(inObject, inPropID, inSpec);
 			break;
@@ -396,7 +393,6 @@ static void xfdashboard_application_class_init(XfdashboardApplicationClass *klas
 
 	/* Override functions */
 	appClass->activate=_xfdashboard_application_activate;
-	appClass->startup=_xfdashboard_application_startup;
 	appClass->command_line=_xfdashboard_application_command_line;
 
 	gobjectClass->dispose=_xfdashboard_application_dispose;
@@ -408,12 +404,19 @@ static void xfdashboard_application_class_init(XfdashboardApplicationClass *klas
 
 	/* Define properties */
 	XfdashboardApplicationProperties[PROP_DAEMONIZED]=
-		g_param_spec_boolean("daemonized",
-								_("Daemonized"),
+		g_param_spec_boolean("is-daemonized",
+								_("is-daemonized"),
 								_("Flag indicating if application is daemonized"),
 								FALSE,
 								G_PARAM_READABLE);
 
+	XfdashboardApplicationProperties[PROP_SUSPENDED]=
+		g_param_spec_boolean("is-suspended",
+								_("Is suspended"),
+								_("Flag indicating if application is suspended currently"),
+								FALSE,
+								G_PARAM_READABLE);
+
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardApplicationProperties);
 
 	/* Define signals */
@@ -438,6 +441,28 @@ static void xfdashboard_application_class_init(XfdashboardApplicationClass *klas
 						g_cclosure_marshal_VOID__VOID,
 						G_TYPE_NONE,
 						0);
+
+	XfdashboardApplicationSignals[SIGNAL_SUSPEND]=
+		g_signal_new("suspend",
+						G_TYPE_FROM_CLASS(klass),
+						G_SIGNAL_RUN_LAST,
+						G_STRUCT_OFFSET(XfdashboardApplicationClass, suspend),
+						NULL,
+						NULL,
+						g_cclosure_marshal_VOID__VOID,
+						G_TYPE_NONE,
+						0);
+
+	XfdashboardApplicationSignals[SIGNAL_RESUME]=
+		g_signal_new("resume",
+						G_TYPE_FROM_CLASS(klass),
+						G_SIGNAL_RUN_LAST,
+						G_STRUCT_OFFSET(XfdashboardApplicationClass, resume),
+						NULL,
+						NULL,
+						g_cclosure_marshal_VOID__VOID,
+						G_TYPE_NONE,
+						0);
 }
 
 /* Object initialization
@@ -450,9 +475,9 @@ static void xfdashboard_application_init(XfdashboardApplication *self)
 	priv=self->priv=XFDASHBOARD_APPLICATION_GET_PRIVATE(self);
 
 	/* Set default values */
-	priv->inited=FALSE;
-	priv->shouldInit=FALSE;
 	priv->isDaemon=FALSE;
+	priv->isSuspended=FALSE;
+	priv->inited=FALSE;
 	priv->xfconfChannel=NULL;
 	priv->viewManager=NULL;
 }
@@ -473,6 +498,22 @@ XfdashboardApplication* xfdashboard_application_get_default(void)
 	return(application);
 }
 
+/* Get flag if application is running in daemonized mode */
+gboolean xfdashboard_application_is_daemonized(XfdashboardApplication *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATION(self), FALSE);
+
+	return(self->priv->isDaemon);
+}
+
+/* Get flag if application is suspended or resumed */
+gboolean xfdashboard_application_is_suspended(XfdashboardApplication *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATION(self), FALSE);
+
+	return(self->priv->isSuspended);
+}
+
 /* Get xfconf channel for this application */
 XfconfChannel* xfdashboard_application_get_xfconf_channel(void)
 {
