@@ -61,21 +61,22 @@ G_DEFINE_TYPE(XfdashboardStage,
 struct _XfdashboardStagePrivate
 {
 	/* Actors */
-	ClutterActor				*quicklaunch;
-	ClutterActor				*searchbox;
-	ClutterActor				*workspaces;
-	ClutterActor				*viewpad;
-	ClutterActor				*viewSelector;
-	ClutterActor				*notification;
+	ClutterActor					*quicklaunch;
+	ClutterActor					*searchbox;
+	ClutterActor					*workspaces;
+	ClutterActor					*viewpad;
+	ClutterActor					*viewSelector;
+	ClutterActor					*notification;
 
 	/* Instance related */
-	XfdashboardWindowTracker	*windowTracker;
+	XfdashboardWindowTracker		*windowTracker;
+	XfdashboardWindowTrackerWindow	*stageWindow;
 
-	gboolean					searchActive;
-	gint						lastSearchTextLength;
-	XfdashboardView				*viewBeforeSearch;
+	gboolean						searchActive;
+	gint							lastSearchTextLength;
+	XfdashboardView					*viewBeforeSearch;
 
-	guint						notificationTimeoutID;
+	guint							notificationTimeoutID;
 };
 
 /* Signals */
@@ -98,7 +99,10 @@ static ClutterColor		defaultNotificationFillColor={ 0x13, 0x50, 0xff, 0xff };		/
 static ClutterColor		defaultNotificationOutlineColor={ 0x63, 0xb0, 0xff, 0xff };		// TODO: Replace by settings/theming object
 
 #define DEFAULT_NOTIFICATION_OUTLINE_WIDTH		1.0f									// TODO: Replace by settings/theming object
-#define DEFAULT_NOTIFICATION_TIMEOUT			3000									// TODO: Replace by settings/theming object
+#define NOTIFICATION_TIMEOUT_XFCONF_PROP		"/min-notification-timeout"
+#define DEFAULT_NOTIFICATION_TIMEOUT			3000
+#define RESET_SEARCH_ON_RESUME_XFCONF_PROP		"/reset-search-on-resume"
+#define DEFAULT_RESET_SEARCH_ON_RESUME			TRUE
 
 /* Notification timeout has been reached */
 static void _xfdashboard_stage_on_notification_timeout_destroyed(gpointer inUserData)
@@ -599,13 +603,106 @@ static void _xfdashboard_stage_on_window_opened(XfdashboardStage *self,
 													geometry.width, geometry.height);
 
 	/* Set up window for use as stage window */
-	xfdashboard_window_tracker_window_make_stage_window(inWindow);
+	priv->stageWindow=inWindow;
+	xfdashboard_window_tracker_window_make_stage_window(priv->stageWindow);
 
 	/* Disconnect signal handler as this is a one-time setup of stage window */
 	g_debug(_("Stage window was opened and set up. Removing signal handler."));
 	g_signal_handlers_disconnect_by_func(priv->windowTracker, G_CALLBACK(_xfdashboard_stage_on_window_opened), self);
 }
 
+/* The application will be suspended */
+static void _xfdashboard_stage_on_application_suspend(XfdashboardStage *self, gpointer inUserData)
+{
+	XfdashboardStagePrivate				*priv=self->priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_STAGE(self));
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inUserData));
+
+	priv=self->priv;
+
+	/* Instead of hiding stage actor just hide stage's window. It should be safe
+	 * to just hide the window as it should be listed on any task list and is not
+	 * selectable by user. The advantage should be that the window is already mapped
+	 * and its state is already set up like fullscreen, sticky and so on. This
+	 * prevents that window will not be shown in fullscreen again (just maximized
+	 * and flickers) if we use clutter_actor_show to show stage actor and its window
+	 * again. But we can only do this if the window is known and set up ;)
+	 */
+	if(priv->stageWindow)
+	{
+		xfdashboard_window_tracker_window_unmake_stage_window(priv->stageWindow);
+		xfdashboard_window_tracker_window_hide(priv->stageWindow);
+	}
+}
+
+/* The application will be resumed */
+static void _xfdashboard_stage_on_application_resume(XfdashboardStage *self, gpointer inUserData)
+{
+	XfdashboardStagePrivate				*priv=self->priv;
+	gboolean							doResetSearch;
+
+	g_return_if_fail(XFDASHBOARD_IS_STAGE(self));
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inUserData));
+
+	priv=self->priv;
+
+	/* If stage window is known just show it again ... */
+	if(priv->stageWindow)
+	{
+		/* If search is active then end search by clearing search box */
+		doResetSearch=xfconf_channel_get_bool(xfdashboard_application_get_xfconf_channel(),
+												RESET_SEARCH_ON_RESUME_XFCONF_PROP,
+												DEFAULT_RESET_SEARCH_ON_RESUME);
+		if(priv->searchbox &&
+			doResetSearch &&
+			!xfdashboard_text_box_is_empty(XFDASHBOARD_TEXT_BOX(priv->searchbox)))
+		{
+			xfdashboard_text_box_set_text(XFDASHBOARD_TEXT_BOX(priv->searchbox), NULL);
+		}
+
+		/* Set up stage and show it */
+		xfdashboard_window_tracker_window_make_stage_window(priv->stageWindow);
+		xfdashboard_window_tracker_window_show(priv->stageWindow);
+	}
+		/* ... otherwise set it up by calling clutter_actor_show() etc. */
+		else
+		{
+			/* Show stage and force window creation */
+			clutter_actor_show(CLUTTER_ACTOR(self));
+		}
+}
+
+/* IMPLEMENTATION: ClutterActor */
+
+/* The stage actor should be shown */
+static void _xfdashboard_stage_show(ClutterActor *inActor)
+{
+	XfdashboardStage			*self;
+	XfdashboardStagePrivate		*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_STAGE(inActor));
+
+	self=XFDASHBOARD_STAGE(inActor);
+	priv=self->priv;
+
+	/* Set stage to fullscreen just in case it forgot about it */
+	clutter_stage_set_fullscreen(CLUTTER_STAGE(self), TRUE);
+
+	/* If we do not know the stage window connect signal to find it */
+	if(!priv->stageWindow)
+	{
+		/* Connect signals */
+		g_signal_connect_swapped(priv->windowTracker, "window-opened", G_CALLBACK(_xfdashboard_stage_on_window_opened), self);
+	}
+
+	/* Call parent's show method */
+	if(CLUTTER_ACTOR_CLASS(xfdashboard_stage_parent_class)->show)
+	{
+		CLUTTER_ACTOR_CLASS(xfdashboard_stage_parent_class)->show(inActor);
+	}
+}
+
 /* IMPLEMENTATION: GObject */
 
 /* Dispose this object */
@@ -615,6 +712,12 @@ static void _xfdashboard_stage_dispose(GObject *inObject)
 	XfdashboardStagePrivate		*priv=self->priv;
 
 	/* Release allocated resources */
+	if(priv->stageWindow)
+	{
+		xfdashboard_window_tracker_window_unmake_stage_window(priv->stageWindow);
+		priv->stageWindow=NULL;
+	}
+
 	if(priv->notificationTimeoutID)
 	{
 		g_source_remove(priv->notificationTimeoutID);
@@ -680,9 +783,12 @@ static void _xfdashboard_stage_dispose(GObject *inObject)
  */
 static void xfdashboard_stage_class_init(XfdashboardStageClass *klass)
 {
+	ClutterActorClass	*actorClass=CLUTTER_ACTOR_CLASS(klass);
 	GObjectClass		*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
+	actorClass->show=_xfdashboard_stage_show;
+
 	gobjectClass->dispose=_xfdashboard_stage_dispose;
 
 	/* Set up private structure */
@@ -730,11 +836,13 @@ static void xfdashboard_stage_class_init(XfdashboardStageClass *klass)
 static void xfdashboard_stage_init(XfdashboardStage *self)
 {
 	XfdashboardStagePrivate		*priv;
+	XfdashboardApplication		*application;
 
 	priv=self->priv=XFDASHBOARD_STAGE_GET_PRIVATE(self);
 
 	/* Set default values */
 	priv->windowTracker=xfdashboard_window_tracker_get_default();
+	priv->stageWindow=NULL;
 
 	priv->quicklaunch=NULL;
 	priv->searchbox=NULL;
@@ -757,8 +865,10 @@ static void xfdashboard_stage_init(XfdashboardStage *self)
 
 	g_signal_connect_swapped(self, "key-release-event", G_CALLBACK(_xfdashboard_stage_on_key_release), self);
 
-	/* Connect signals */
-	g_signal_connect_swapped(priv->windowTracker, "window-opened", G_CALLBACK(_xfdashboard_stage_on_window_opened), self);
+	/* Connect signal to application */
+	application=xfdashboard_application_get_default();
+	g_signal_connect_swapped(application, "suspend", G_CALLBACK(_xfdashboard_stage_on_application_suspend), self);
+	g_signal_connect_swapped(application, "resume", G_CALLBACK(_xfdashboard_stage_on_application_resume), self);
 }
 
 /* IMPLEMENTATION: Public API */
@@ -797,7 +907,11 @@ void xfdashboard_stage_show_notification(XfdashboardStage *self, const gchar *in
 	 * of the notification text to show but never drops below the minimum timeout configured.
 	 * The interval is calculated by one second for 30 characters.
 	 */
-	interval=MAX((gint)((strlen(inText)/30.0f)*1000.0f), DEFAULT_NOTIFICATION_TIMEOUT);
+	interval=xfconf_channel_get_uint(xfdashboard_application_get_xfconf_channel(),
+										NOTIFICATION_TIMEOUT_XFCONF_PROP,
+										DEFAULT_NOTIFICATION_TIMEOUT);
+	interval=MAX((gint)((strlen(inText)/30.0f)*1000.0f), interval);
+
 	priv->notificationTimeoutID=clutter_threads_add_timeout_full(G_PRIORITY_DEFAULT,
 																	interval,
 																	_xfdashboard_stage_on_notification_timeout,
